pub struct TransparentSectionContext {
pub root_base_dir: PathBuf,
pub split_paths: Vec<Vec<&'static str>>,
pub transparent_paths: Vec<Vec<&'static str>>,
pub full_schema: Value,
}Expand description
Runtime metadata used to adapt transparent array sections during loading.
Fields
root_base_dir: PathBufRoot config directory used to resolve split section template paths.
split_paths: Vec<Vec<&'static str>>Split section paths marked with x-tree-split.
transparent_paths: Vec<Vec<&'static str>>Split section paths marked with x-tree-transparent-array.
full_schema: ValueFull root JSON Schema used to resolve inner field names.
Implementations
Sourceimpl TransparentSectionContext
impl TransparentSectionContext
Sourcepub fn for_schema<S>(root_config_path: &Path) -> ConfigResult<Self>where
S: ConfigSchema + JsonSchema,
pub fn for_schema<S>(root_config_path: &Path) -> ConfigResult<Self>where
S: ConfigSchema + JsonSchema,
Builds transparent section metadata for one config schema type.
Sourcepub fn section_path_for_file<S>(&self, path: &Path) -> Option<Vec<&'static str>>where
S: ConfigSchema,
pub fn section_path_for_file<S>(&self, path: &Path) -> Option<Vec<&'static str>>where
S: ConfigSchema,
Returns the split section path represented by one config file, if any.
Sourcepub fn is_transparent_section(&self, section_path: &[&str]) -> bool
pub fn is_transparent_section(&self, section_path: &[&str]) -> bool
Returns whether one section path serializes as a transparent array.
Sourcepub fn inner_field_for_section(&self, section_path: &[&str]) -> String
pub fn inner_field_for_section(&self, section_path: &[&str]) -> String
Returns the confique inner field for one transparent section path.