split_section_paths

Function split_section_paths 

pub fn split_section_paths<S>(full_schema: &Value) -> Vec<Vec<&'static str>>
where S: ConfigSchema,
Finds nested sections whose field schema opts into template/schema splitting.

Type Parameters

  • S: Config schema type whose metadata supplies nested section paths.

Arguments

  • full_schema: Full root schema containing x-tree-split markers.

Returns

Returns nested section paths that should be split.

Examples

let _ = ();