Module reference

Module reference 

Local $ref resolution and schema-map reference collection.

Functions

collect_schema_refs
Walks a schema value and collects local references to schema maps.
collect_transitive_schema_refs
Expands the reference set with references used by already retained schemas.
resolve_schema_reference
Resolves the local schema reference shape emitted by schemars.
retain_schema_map
Retains only referenced entries in a root schema map.