pub enum IncludeOrder {
Declared,
Reverse,
}Expand description
Controls the order in which sibling include paths are traversed.
Variants
Declared
Visit include paths in the order they were declared.
Reverse
Visit sibling include paths in reverse declaration order.