pub struct TemplateTarget { /* private fields */ }Expand description
A source-to-output mapping for one generated config template.
The source path is used to discover includes. The target path is the output file that should receive the rendered template content.
Implementations
Sourceimpl TemplateTarget
Accessors for generated template target metadata.
impl TemplateTarget
Accessors for generated template target metadata.
Sourcepub fn source_path(&self) -> &Path
pub fn source_path(&self) -> &Path
Returns the config source path used to discover this target’s includes.
Arguments
self: Template target being inspected.
Returns
Returns the source path for this template target.
Examples
use std::{io, path::{Path, PathBuf}};
use rust_config_tree::collect_template_targets;
let targets = collect_template_targets(
"config.yaml",
"config.example.yaml",
|_path: &Path| -> io::Result<Vec<PathBuf>> { Ok(Vec::new()) },
)?;
assert!(targets[0].source_path().ends_with("config.example.yaml"));Sourcepub fn target_path(&self) -> &Path
pub fn target_path(&self) -> &Path
Returns the output path that should receive this target’s template.
Arguments
self: Template target being inspected.
Returns
Returns the output path for this template target.
Examples
use std::{io, path::{Path, PathBuf}};
use rust_config_tree::collect_template_targets;
let targets = collect_template_targets(
"config.yaml",
"config.example.yaml",
|_path: &Path| -> io::Result<Vec<PathBuf>> { Ok(Vec::new()) },
)?;
assert_eq!(targets[0].target_path(), Path::new("config.example.yaml"));Sourcepub fn include_paths(&self) -> &[PathBuf]
pub fn include_paths(&self) -> &[PathBuf]
Returns include paths declared by this source target.
Arguments
self: Template target being inspected.
Returns
Returns the include paths declared by the target source.
Examples
use std::{io, path::{Path, PathBuf}};
use rust_config_tree::collect_template_targets;
let targets = collect_template_targets(
"config.yaml",
"config.example.yaml",
|path: &Path| -> io::Result<Vec<PathBuf>> {
if path.ends_with("config.example.yaml") {
Ok(vec![PathBuf::from("child.yaml")])
} else {
Ok(Vec::new())
}
},
)?;
assert_eq!(targets[0].include_paths(), &[PathBuf::from("child.yaml")]);Sourcepub fn into_parts(self) -> (PathBuf, PathBuf, Vec<PathBuf>)
pub fn into_parts(self) -> (PathBuf, PathBuf, Vec<PathBuf>)
Decomposes the target into its source path, target path, and include paths.
Arguments
self: Template target to decompose.
Returns
Returns (source_path, target_path, include_paths).
Examples
use std::{io, path::{Path, PathBuf}};
use rust_config_tree::collect_template_targets;
let mut targets = collect_template_targets(
"config.yaml",
"config.example.yaml",
|_path: &Path| -> io::Result<Vec<PathBuf>> { Ok(Vec::new()) },
)?;
let (_source_path, target_path, include_paths) = targets.remove(0).into_parts();
assert_eq!(target_path, PathBuf::from("config.example.yaml"));
assert!(include_paths.is_empty());Trait Implementations
Sourceimpl Clone for TemplateTarget
impl Clone for TemplateTarget
Sourcefn clone(&self) -> TemplateTarget
fn clone(&self) -> TemplateTarget
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TemplateTarget
impl Debug for TemplateTarget
Sourceimpl PartialEq for TemplateTarget
impl PartialEq for TemplateTarget
impl Eq for TemplateTarget
impl StructuralPartialEq for TemplateTarget