pub type BoxError = Box<dyn Error + Send + Sync + 'static>;Expand description
Boxed error type used by custom loaders.
Loader errors are boxed so tree traversal can accept different concrete error types through a single public API.
Aliased Type
pub struct BoxError(/* private fields */);