pub fn install_shell_completion<C>(shell: Shell) -> ConfigResult<()>where
C: CommandFactory,Expand description
Generates shell completion files and updates shell startup files when needed.
Type Parameters
C: The consumer CLI parser type used to build the clap command.
Arguments
shell: Shell whose completion file should be installed.
Returns
Returns Ok(()) after the completion file is generated and any required
startup file has been updated.