Function print_shell_completion
Source pub fn print_shell_completion<C>(shell: Shell)
Writes shell completion output to stdout.
Type Parameters
C: The consumer CLI parser type used to build the clap command.
Arguments
shell: Shell whose completion script should be generated.
Returns
This function writes to stdout and returns no value.