resolve_include_path

Function resolve_include_path 

pub fn resolve_include_path(
    parent_path: impl AsRef<Path>,
    include_path: impl AsRef<Path>,
) -> PathBuf
Resolves an include path relative to the file that declared it.

Absolute include paths are only normalized. Relative include paths are joined to the parent directory of parent_path and then normalized.

Arguments

  • parent_path: Path of the config file that declared the include.
  • include_path: Include path declared by parent_path.

Returns

Returns the normalized resolved include path.