pub struct ConfigSource<T> { /* private fields */ }Expand description
Value and includes returned by a config source loader.
Type Parameters
T: Loaded source value type.
Implementations
Sourceimpl<T> ConfigSource<T>
impl<T> ConfigSource<T>
Sourcepub fn new(value: T, includes: Vec<PathBuf>) -> Self
pub fn new(value: T, includes: Vec<PathBuf>) -> Self
Creates a source from a loaded value and its declared include paths.
Arguments
value: Loaded source value.includes: Include paths declared by the source.
Returns
Returns a new ConfigSource.
Sourcepub fn includes(&self) -> &[PathBuf]
pub fn includes(&self) -> &[PathBuf]
Returns include paths declared by the source.
Returns
Returns the include paths declared by the source.
Sourcepub fn into_parts(self) -> (T, Vec<PathBuf>)
pub fn into_parts(self) -> (T, Vec<PathBuf>)